Crate cargo_exe_v2

Crate cargo_exe_v2 

A very simple tool to print the executable output of cargo build.

Enums

Mode
Operational behavior. Represents the approach taken to finding an executable file path.

Constants

DIR_DEBUG
Name of the output directory for the Debug profile.
DIR_RELEASE
Name of the output directory for the Release profile.
DIR_TARGET
Name of the directory which contains all output directories.
FILE_MANIFEST
Name of the crate manifest file.

Functions

names_bin
Given a path to a Cargo.toml crate manifest, read the manifest and attempt to return the names of all executable binaries generated by the project.
path_project
If the given Path is a file, return its parent directory. Otherwise, return it unchanged.