Mode

Enum Mode 

pub enum Mode {
    Debug,
    Release,
    Latest,
}
Operational behavior. Represents the approach taken to finding an executable file path.

Variants



Debug

The executable is assumed to be within /target/debug/.



Release

The executable is assumed to be within /target/release/.



Latest

The entirely of /target/**/ will be searched, and the path to the most recently modified executable will be returned.

Implementations

Source

impl Mode

pub fn make_path( &self, path_dir_target: impl Into<PathBuf>, path_exe: impl AsRef<Path>, ) -> Option<PathBuf>

Given a path to a target/ directory and the name of an executable file, return a path to the file according to the defined behavior.

Returns None if the mode is Latest and the file cannot be found anywhere in the target directory.