A very simple tool to print the executable output of cargo build.
Enums
- Mode
- Operational behavior. Represents the approach taken to finding an executable file path.
Constants
- DIR_
DEBUG - Name of the output directory for the Debug profile.
- DIR_
RELEASE - Name of the output directory for the Release profile.
- DIR_
TARGET - Name of the directory which contains all output directories.
- FILE_
MANIFEST - Name of the crate manifest file.
Functions
- names_
bin - Given a path to a
Cargo.tomlcrate manifest, read the manifest and attempt to return the names of all executable binaries generated by the project. - path_
project - If the given Path is a file, return its parent directory. Otherwise, return it unchanged.